@@ -1,5 +1,5 @@
 # UMLS::Interface::ICFinder
-# (Last Updated $Id: ICFinder.pm,v 1.19 2011/01/12 20:25:17 btmcinnes Exp $)
+# (Last Updated $Id: ICFinder.pm,v 1.2 2010/05/20 14:54:43 btmcinnes Exp $)
 #
 # Perl module that provides a perl interface to the
 # Unified Medical Language System (UMLS)
@@ -46,7 +46,7 @@ use warnings;
 use DBI;
 use bytes;
 
-my $pkg = "UMLS::Interface::ICFinder";
+use UMLS::Interface::CuiFinder;
 
 my $root = "";
 
@@ -62,12 +62,9 @@ my %frequencyHash = ();
 
 my $option_icpropagation = 0;
 my $option_icfrequency   = 0;
-my $option_t             = 0;
-my $smooth               = 0;
-my $configN              = 0;
+my $option_t           = 0;
 
-my $errorhandler = "";
-my $cuifinder    = "";
+my $smooth             = 1;
 
 # UMLS-specific stuff ends ----------
 
@@ -77,30 +74,18 @@ my $cuifinder    = "";
 sub new {
     my $self = {};
     my $className = shift;
-    my $params    = shift;
-    my $handler   = shift;
+    my $paramHash = shift;
+    my $cuifinder = shift;
     
-    # initialize error handler
-    $errorhandler = UMLS::Interface::ErrorHandler->new();
-    if(! defined $errorhandler) {
-	print STDERR "The error handler did not get passed properly.\n";
-	exit;
-    }
-    
-    #  initialize the cuifinder
-    $cuifinder = $handler;
-    if(! (defined $handler)) { 
-	$errorhandler->_error($pkg, 
-			      "new", 
-			      "The CuiFinder handler did not get passed properly", 
-			      8);
-    }
+    # Initialize Error String and Error Code.
+    $self->{'errorString'} = "";
+    $self->{'errorCode'} = 0;
 
-    # bless the object.
+    # Bless the object.
     bless($self, $className);
 
-    # initialize the object.
-    $self->_initialize($params);
+    # Initialize the object.
+    $self->_initialize($paramHash, $cuifinder);
 
     return $self;
 }
@@ -110,26 +95,32 @@ sub _initialize
 {
     my $self      = shift;
     my $params    = shift;
+    my $cuifinder = shift;
+
+    return undef if(!defined $self || !ref $self);
+    
+    $params = {} if(!defined $params);
 
     #  set function name
     my $function = "_initialize";
-    &_debug($function);
+
+    #  check the cuifinder
+    if(!$cuifinder) { 
+	return($self->_error($function, "No UMLS::Interface::CuiFinder")); 
+    } $self->{'cuifinder'} = $cuifinder;
     
-    #  check self
-    if(!defined $self || !ref $self) {
-	$errorhandler->_error($pkg, $function, "", 2);
-    }
-        
     #  get the umlsinterfaceindex database from CuiFinder
     my $sdb = $cuifinder->_getIndexDB();
-    if(!$sdb) { $errorhandler->_error($pkg, $function, "Error with sdb.", 3); }
-    $self->{'sdb'} = $sdb;
-    
+    if(!$sdb) { 
+	return($self->_error($function, "No db sent from UMLS::Interface::CuiFinder")); 
+    } $self->{'sdb'} = $sdb;
+
     #  get the root
     $root = $cuifinder->_root();
 
     #  set up the options
     $self->_setOptions($params);
+    if($self->_checkError($function)) { return (); }	
 
     #  load the propagation hash if the option is specified
     if($option_icpropagation) { 
@@ -158,14 +149,11 @@ sub _setOptions
 {
     my $self = shift;
     my $params = shift;
- 
-    my $function = "_setOptions";
     
-    #  check self
-    if(!defined $self || !ref $self) {
-	$errorhandler->_error($pkg, $function, "", 2);
-    }
- 
+    return undef if(!defined $self || !ref $self);
+
+    my $function = "_setOptions";
+
     #  get all the parameters
     my $debugoption   = $params->{'debug'};
     my $t             = $params->{'t'};
@@ -189,7 +177,7 @@ sub _setOptions
     
     if(defined $icsmooth) {
 	$smooth = $icsmooth;
-	$output .= "  --smooth\n";
+	$output .= "   --smooth $smooth\n";
     }
 
     #  check if the propagation option has been identified
@@ -216,15 +204,78 @@ sub _setOptions
     }    
 }
 
-#  returns the configN - the total number of CUIs
-sub _getN
-{
+#  set the error string
+#  input : $function <- the function the error is coming from
+#          $string   <- the error string
+#  output: 
+sub _error {
+
+    my $self     = shift;
+    my $function = shift;
+    my $string   = shift;
+
+    return undef if(!defined $self || !ref $self);
+        
+    $self->{'errorString'} .= "\nError (UMLS::Interface::PathFinder->$function()) - ";
+    $self->{'errorString'} .= $string;
+    $self->{'errorCode'} = 2;
+
+}
+
+#  check error function to determine if an error happened within a function
+#  input : $function <- string containing name of function
+#  output: 0|1 indicating if an error has been thrown 
+sub _checkError {
+    my $self     = shift;
+    my $function = shift;
+   
+    my $code = $self->{'errorCode'}; 
+    
+    my $sdb = $self->{'sdb'};
+    if($sdb->err()) { 
+	$self->_error($function, 
+		      "Error executing database query: ($sdb->errstr())");
+	return 1;
+    }
+    
+    if($code == 2) { return 1; }
+    else           { return 0; }
+}
+
+#  method that returns the error string and error code from the 
+#  last method call on the object.
+#  input : 
+#  output: $returnCode, $returnString <- strings containing 
+#                                        error information
+sub _getError {
+    my $self      = shift;
+
+    my $returnCode = $self->{'errorCode'};
+    my $returnString = $self->{'errorString'};
+
+    $returnString =~ s/^\n+//;
+
+    return ($returnCode, $returnString);
+}
+
+#  method sets the error - this is for when we call
+#  something in another pm module we can propagate
+#  that erro back through the program
+#  input : $handler
+#  output: 
+sub _setError {
     my $self = shift;
+    my $handler = shift;
 
-    my $function = "_getN";
+    my $function = "_setError";
     &_debug($function);
-
-    return $configN;
+    
+    #  set the cuifinder 
+    
+    my ($returnCode, $returnString) = $handler->_getError();
+    
+    $self->{'returnCode'}   = $returnCode;
+    $self->{'returnString'} = $returnString;
 }
 
  
@@ -236,23 +287,27 @@ sub _getIC
     my $self     = shift;
     my $concept  = shift;
 
+    return undef if(!defined $self || !ref $self);
+    
     my $function = "_getIC";
     &_debug($function);
 
-     #  check self
-    if(!defined $self || !ref $self) {
-	$errorhandler->_error($pkg, $function, "", 2);
-    }
-     
     #  check concept was obtained
     if(!$concept) { 
-	$errorhandler->_error($pkg, $function, "Error with input variable \$concept.", 4);
+	return($self->_error($function, "Undefined input values.")); 
+    }
+    
+    #  set the cuifinder 
+    my $cuifinder = $self->{'cuifinder'};
+    if(!$cuifinder) { 
+	return($self->_error($function, "UMLS::Interface::CuiFinder not defined.")); 
+    }
+    
+    #  check valid concept
+    if($cuifinder->_validCui($concept)) { 
+	return($self->_error($function, "Incorrect input value ($concept).")); 
     }
     
-    #  check if valid concept
-    if(! ($errorhandler->_validCui($concept)) ) {
-	$errorhandler->_error($pkg, $function, "Concept ($concept) in not valid.", 6);
-    }    
        
     #  if option frequency then the propagation hash 
     #  hash has not been loaded and we should determine
@@ -276,120 +331,10 @@ sub _getIC
     }
     
     my $prob = $propagationHash{$concept};
-
+    
     if(!defined $prob) { return 0; }
 
-    my $ic = 0;
-    if($prob > 0 and $prob < 1) { $ic = -1 * (log($prob) / log(10)); }    
-    return $ic;
-}
-
- 
-#  returns the probability
-#  input : $concept <- string containing a cui
-#  output: $double  <- double containing its probability
-sub _getProbability
-{
-    my $self     = shift;
-    my $concept  = shift;
-
-    my $function = "_getIC";
-    &_debug($function);
-
-     #  check self
-    if(!defined $self || !ref $self) {
-	$errorhandler->_error($pkg, $function, "", 2);
-    }
-     
-    #  check concept was obtained
-    if(!$concept) { 
-	$errorhandler->_error($pkg, $function, "Error with input variable \$concept.", 4);
-    }
-    
-    #  check if valid concept
-    if(! ($errorhandler->_validCui($concept)) ) {
-	$errorhandler->_error($pkg, $function, "Concept ($concept) in not valid.", 6);
-    }    
-       
-    #  if option frequency then the propagation hash 
-    #  hash has not been loaded and we should determine
-    #  the information content of the concept using the
-    #  frequency information in the file in realtime
-    if($option_icfrequency) { 
-	
-  	#  initialize the propagation hash
-	$self->_initializePropagationHash();
-	
-	#  load the propagation frequency hash
-	$self->_loadPropagationFreq(\%frequencyHash);
-	
-	#  propogate the counts
-	&_debug("_propagation");
-	my @array = ();
-	$self->_propagation($concept, \@array);
-	
-	#  tally up the propagation counts
-	$self->_tallyCounts();
-    }
-    
-    my $prob = $propagationHash{$concept};
-
-	
-    if(!defined $prob) { return 0; }
-
-    return $prob;
-}
-
-#  returns the propagation count (frequency)  of a cui
-#  input : $concept <- string containing a cui
-#  output: $double  <- frequency
-sub _getFrequency
-{
-    my $self     = shift;
-    my $concept  = shift;
-
-    my $function = "_getFrequency";
-    &_debug($function);
-
-     #  check self
-    if(!defined $self || !ref $self) {
-	$errorhandler->_error($pkg, $function, "", 2);
-    }
-     
-    #  check concept was obtained
-    if(!$concept) { 
-	$errorhandler->_error($pkg, $function, "Error with input variable \$concept.", 4);
-    }
-    
-    #  check if valid concept
-    if(! ($errorhandler->_validCui($concept)) ) {
-	$errorhandler->_error($pkg, $function, "Concept ($concept) in not valid.", 6);
-    }    
-       
-    #  if option frequency then the propagation hash 
-    #  hash has not been loaded and we should determine
-    #  the information content of the concept using the
-    #  frequency information in the file in realtime
-    if($option_icfrequency) { 
-	
-  	#  initialize the propagation hash
-	$self->_initializePropagationHash();
-	
-	#  load the propagation frequency hash
-	$self->_loadPropagationFreq(\%frequencyHash);
-	
-	#  propogate the counts
-	&_debug("_propagation");
-	my @array = ();
-	$self->_propagation($concept, \@array);
-	
-	#  tally up the propagation counts
-	$self->_tallyCounts();
-    }
-
-    my $freq = int($propagationHash{$concept} * $configN);
-
-    return $freq;
+    return ($prob > 0 and $prob < 1) ? -log($prob) : 0;
 }
 
 #  this method obtains the CUIs in the sources which 
@@ -400,28 +345,12 @@ sub _loadFrequencyHash {
 
     my $self = shift;
     
-    my $function = "_loadFrequencyHash";
-
-    #  check self
-    if(!defined $self || !ref $self) {
-	$errorhandler->_error($pkg, $function, "", 2);
-    }
-
-    #  open the frequency file
-    open(FILE, $frequencyFile) || die "Could not open file $frequencyFile\n";
-
-    #  obtain the frequency counts storing them in the frequency hash table
+    open(FILE, $frequencyFile) || die "Could not open file: $frequencyFile\n";
+    
     while(<FILE>) { 
 	chomp;
-	
-	#  if blank line more on
-	if($_=~/^\s*$/) { next; }
-
-	#  get the cui and its frequency count
 	my($cui, $freq) = split/<>/;
 	
-	#  make certain that it is a cui and a frequency
-	#  and if it is load it into the frequency hash
 	if( ($cui=~/C[0-9]/) && ($freq=~/[0-9]+/) ) { 
 	    if(exists $frequencyHash{$cui}) { 
 		$frequencyHash{$cui} += $freq;
@@ -443,16 +372,27 @@ sub _getPropagationCuis {
 
     my $self = shift;
     
+    return undef if(!defined $self || !ref $self);
+    
     my $function = "_getPropagationCuis";
     &_debug($function);
-
-    #  check self
-    if(!defined $self || !ref $self) {
-	$errorhandler->_error($pkg, $function, "", 2);
+    
+    #  set the cuifinder 
+    my $cuifinder = $self->{'cuifinder'};
+    if(!$cuifinder) { 
+	return($self->_error($function, "UMLS::Interface::CuiFinder not defined.")); 
     }
+    
+    #  get the hash
+    my $hash = $cuifinder->_getCuiList();
 
-    #  return the reference to a hash
-    return $cuifinder->_getCuiList();
+    #  make certain there weren't any problems
+    if($self->_checkError($cuifinder)) { 
+	$self->_setError($cuifinder);
+	return; 
+    }
+    
+    return $hash;
 }
 
 #  initialize the propgation hash
@@ -462,17 +402,16 @@ sub _initializePropagationHash {
 
     my $self = shift;
 
+    return undef if(!defined $self || !ref $self);
+    
     my $function = "_initializePropagationHash";
     &_debug($function);
-
-    #  check self
-    if(!defined $self || !ref $self) {
-	$errorhandler->_error($pkg, $function, "", 2);
-    }
     
     #  clear out the hash just in case
     my $hash = $self->_getPropagationCuis();
-       
+        
+    if($debug) { print STDERR "SMOOTH: $smooth\n"; }
+
     #  add the cuis to the propagation hash
     foreach my $cui (sort keys %{$hash}) { 
 	$propagationHash{$cui} = "";
@@ -488,206 +427,58 @@ sub _loadPropagationFreq {
     my $self = shift;
     my $fhash = shift;
     
+    return undef if(!defined $self || !ref $self);
+    
     my $function = "_loadPropagationFreq";
     &_debug($function);
 
-    #  check self
-    if(!defined $self || !ref $self) {
-	$errorhandler->_error($pkg, $function, "", 2);
-    }
-
     #  loop through and set the frequency count
     my $N = 0;    
     foreach my $cui (sort keys %{$fhash}) {
-	if($cui=~/^\s*$/) { next; }
-	
 	my $freq = ${$fhash}{$cui};
 	if(exists $propagationFreq{$cui}) {
 	    $propagationFreq{$cui} += $freq;
 	}
-	$N = $N + $freq;
+	$N+= $freq;
     }
     
+
     #  check if something has been set
     if($smooth == 1) { 
 	my $pkeys = keys %propagationFreq;
 	$N += $pkeys;
     }
     
-    #  set N for the config file
-    $configN = $N;
-
     #  loop through again and set the probability
     foreach my $cui (sort keys %propagationFreq) { 
-	$propagationFreq{$cui} = ($propagationFreq{$cui}) / $N;
-	
+	$propagationFreq{$cui} = $propagationFreq{$cui} / $N;
     }
 }
 
-#  check that the parameters in config file match
-#  input : $string1 <- string containing parameter
-#          $string2 <- string containing configuratation parameter
-#  output: 0|1      <- true or false
-sub _checkParameters {
-    my $self = shift;
-    my $string1 = shift;
-    my $string2 = shift;
-
-    my $function = "_checkParameters";
-    &_debug($function);
-
-    if( !(defined $string1) && !(defined $string2) ) { return 1; }
-    if( ($string1=~/^\s*$/) && ($string2=~/^\s*$/) ) { return 1; }
-    if( ($string1=~/^\s*$/) && !($string2=~/^\s*$/) ) { return 0; }
-    if( !($string1=~/^\s*$/) && ($string2=~/^\s*$/) ) { return 0; }
-
-    	
-    $string1=~/([A-Z]+) :: (include|exclude) (.*?)$/;
-    my $option1 = $1;
-    my $type1   = $2;
-    my $param1  = $3;
-    
-    $string2=~/([A-Z]+) :: (include|exclude) (.*?)$/;
-    my $option2 = $1;
-    my $type2   = $2;
-    my $param2  = $3;
-
-    if($option1 ne $option2) { return 0; }
-    if($type1 ne $type2)     { return 0; }
-
-    my @array1 = split/\,/, $param1;
-    my @array2 = split/\,/, $param2;
-    
-
-    my %hash = ();
-
-    foreach my $element (@array1) { $element=~s/\s+//g; $hash{$element}++; }
-    foreach my $element (@array2) { $element=~s/\s+//g; $hash{$element}++; }
-    
-    foreach my $element (sort keys %hash) { 
-	if($hash{$element} != 2) { return 0; }
-    }    
-
-    return 1;
-}
-
-#  check that the relations used are only RB/RN and/or PAR/CHD relations
-#  input : string  <- contain the relation line from config file
-#  output: 1|0     <- indicating if the string contains relations other 
-#                     than RB/RN or PAR/CHD relations
-sub _checkHierarchicalRelations {
-    
-    my $self = shift;
-    my $string  = shift;
-
-    my $function = "_checkHierarchicalRelations";
-    &_debug($function);
-
-    $string=~/([A-Z]+) :: (include|exclude) (.*?)$/;
-    my $option = $1;
-    my $type   = $2;
-    my $param  = $3;
-    
-    $param=~s/\s+//g;
-
-    my @rels = split/\s*\,\s*/, $param; 
-    
-    foreach my $rel (@rels) { 
-	if( !($rel=~/(PAR|CHD|RB|RN)/) ) { 
-	    return 0;
-	}
-    }
-    
-    return 1;
-}
-
 #  load the propagation hash
 #  input :
 #  output: 
 sub _loadPropagationHash {
 
     my $self = shift;
-        
+    
+    return undef if(!defined $self || !ref $self);
+    
     my $function = "_loadPropagationHash";
     &_debug($function);
 
-    #  check self
-    if(!defined $self || !ref $self) {
-	$errorhandler->_error($pkg, $function, "", 2);
-    }
-
-    #  open the propagation file
     open(FILE, $propagationFile) || die "Could not open file $propagationFile\n";
-    #  check if smoothing was set
-    my $psmooth = <FILE>;
-    
-    #  get the source and relations associated with the propagation file
-    my $sab  = <FILE>; chomp $sab;
-    my $rel  = <FILE>; chomp $rel;
-
-    #  get the rela realtions associated with the propagation file if one exists
-    my $rela = <FILE>; chomp $rela;
-
-    #  if it does exist in then get N otherwise we got N already.
-    my $ninfo = $rela;
-    if($rela=~/RELA/) { 
-	$ninfo = <FILE>; chomp $ninfo; 
-    }
-    else { 
-	$rela = "";
-    }
-
-    $ninfo=~/N\s*\:\:\s*([0-9]+)/;
-    $configN = $1;
-
-    #  get the source and relations from config file or the defaults
-    my $configsab = $cuifinder->_getSabString();
-    my $configrel = $cuifinder->_getRelString();
-    
-    #  check the source information is correct
-    if(! ($self->_checkParameters($configsab, $sab)) ) {
-	my $str = "SAB information ($sab) does not match the config file ($configsab).";
-	$errorhandler->_error($pkg, $function, $str, 5);	
-       }
-    
-    #  check that that the relation information is correct
-    if(! ($self->_checkParameters($configrel, $rel)) ) { 
-	my $str = "REL information ($rel) does not match the config file ($configrel).";
-	$errorhandler->_error($pkg, $function, $str, 5);
-    }
-    
-    #  check if rela information was used
-    if($rela ne "") { 
-	if(!($self->_checkParameters($_, $cuifinder->_getRelaString()))) {
-	    my $str = "RELA information does not match the config file ($_).";
-	    $errorhandler->_error($pkg, $function, $str, 5);
-	}
-    }
-    #  check that the relations used are acceptable for propagation
-    #  the only acceptable relations are RB/RN and PAR/CHD
-    if(! ($self->_checkHierarchicalRelations ($configrel)) ) { 
-	my $str = "REL information ($rel) contains relations other than RB/RN and PAR/CHD.";
-	$errorhandler->_error($pkg, $function, $str, 11);
-    }
-    
     while(<FILE>) {
 	chomp;
-	
-	#  if blank line move on
-	if($_=~/^\s*$/) { next; }
-	
-	#  get the cui and its frequency count
 	my ($cui, $freq) = split/<>/;
-
-	#  load it into the propagation hash
 	if(! (exists $propagationHash{$cui})) { 
 	    $propagationHash{$cui} = 0;
 	}
+
 	$propagationHash{$cui} += $freq;
     }
 }
 
-#  DEBUNKED FUNCTION? CHECK
 #  get the propagation count for a given cui
 #  input : $concept   <- string containing the cui
 #  output: $double|-1 <- the propagation count otherwise
@@ -700,23 +491,23 @@ sub _getPropagationCount {
     my $function = "_getPropagationCount";
     &_debug($function);
 
-    #  check self
-    if(!defined $self || !ref $self) {
-	$errorhandler->_error($pkg, $function, "", 2);
-    }
+    $self->_propagateCounts();
 
     #  check concept was obtained
     if(!$concept) { 
-	$errorhandler->_error($pkg, $function, "Error with input variable \$concept.", 4);
+	return($self->_error($function, "Undefined input values.")); 
     }
     
-    #  check if valid concept
-    if(! ($errorhandler->_validCui($concept)) ) {
-	$errorhandler->_error($pkg, $function, "Concept ($concept) in not valid.", 6);
+    #  set the cuifinder 
+    my $cuifinder = $self->{'cuifinder'};
+    if(!$cuifinder) { 
+	return($self->_error($function, "UMLS::Interface::CuiFinder not defined.")); 
+    }
+    
+    #  check valid concept
+    if($cuifinder->_validCui($concept)) { 
+	return($self->_error($function, "Incorrect input value ($concept).")); 
     }
-
-    #  propagate the counts
-    $self->_propagateCounts();
 
     #  if the concept exists in the propagation hash 
     #  return the probability otherwise return a -1
@@ -738,19 +529,11 @@ sub _propagateCounts {
     my $self = shift;    
     my $fhash = shift;
     
+    return undef if(!defined $self || !ref $self);
+    
     my $function = "_propagateCounts";
     &_debug($function);
-
-    #  check self
-    if(!defined $self || !ref $self) {
-	$errorhandler->_error($pkg, $function, "", 2);
-    }
-
-    #  check the parameters
-    if(!defined $fhash) { 
-	$errorhandler->_error($pkg, $function, "Input variable \%fhash  not defined.", 4);
-    }
-
+    
     #  initialize the propagation hash
     $self->_initializePropagationHash();
     
@@ -778,28 +561,24 @@ sub _tallyCounts {
 
     my $self = shift;
     
+    return undef if(!defined $self || !ref $self);
+    
     my $function = "_tallyCounts";
     &_debug($function);
-
-    #  check self
-    if(!defined $self || !ref $self) {
-	$errorhandler->_error($pkg, $function, "", 2);
-    }
     
     foreach my $cui (sort keys %propagationHash) {
 	my $set    = $propagationHash{$cui};
 	my $pcount = $propagationFreq{$cui};
-	
-	if(defined $set) { 
-	    my %hash = ();
-	    while($set=~/(C[0-9][0-9][0-9][0-9][0-9][0-9][0-9])/g) {
-		my $c = $1;
-		if(! (exists $hash{$c}) ) {
-		    $pcount += $propagationFreq{$c};
-		    $hash{$c}++;
-		}
-	    }	
+
+	my %hash = ();
+	while($set=~/(C[0-9][0-9][0-9][0-9][0-9][0-9][0-9])/g) {
+	    my $c = $1;
+	    if(! (exists $hash{$c}) ) {
+		$pcount += $propagationFreq{$c};
+		$hash{$c}++;
+	    }
 	}
+	
 	$propagationHash{$cui} = $pcount;
     }
 }
@@ -818,25 +597,26 @@ sub _propagation {
     my $array   = shift;
 
     my $function = "_propagation";
-
-    #  check self
-    if(!defined $self || !ref $self) {
-	$errorhandler->_error($pkg, $function, "", 2);
-    }
     
-    #  check concept was obtained
+   #  check concept was obtained
     if(!$concept) { 
-	$errorhandler->_error($pkg, $function, "Error with input variable \$concept.", 4);
+	return($self->_error($function, "Undefined input values.")); 
     }
     
-    #  check if valid concept
-    if(! ($errorhandler->_validCui($concept)) ) {
-	$errorhandler->_error($pkg, $function, "Concept ($concept) in not valid.", 6);
+    #  set the cuifinder 
+    my $cuifinder = $self->{'cuifinder'};
+    if(!$cuifinder) { 
+	return($self->_error($function, "UMLS::Interface::CuiFinder not defined.")); 
     }
     
+    #  check valid concept
+    if($cuifinder->_validCui($concept)) { 
+	return($self->_error($function, "Incorrect input value ($concept).")); 
+    }
+ 
     #  if the concept is inactive
     if($cuifinder->_forbiddenConcept($concept)) { return; }
-
+       
     #  set up the new path
     my @intermediate = @{$array};
     push @intermediate, $concept;
@@ -857,7 +637,8 @@ sub _propagation {
 
     #  get all the children
     my @children = $cuifinder->_getChildren($concept);
-
+    if($cuifinder->_checkError("UMLS::Interface::CuiFinder::getChildren")) { return (); }
+    
     #  search through the children   
     foreach my $child (@children) {
 
@@ -879,10 +660,8 @@ sub _propagation {
     }
     
     #  remove duplicates from the set
-    my $rset;
-    if(defined $set) { 
-	$rset = _breduce($set); 
-    }
+    my $rset = _breduce($set);
+
     #  store the set in the propagation hash
     $propagationHash{$concept} = $rset;
     
@@ -893,9 +672,6 @@ sub _propagation {
     return $rset;
 }
 
-#  removes duplicates in an array
-#  input : $array <- reference to an array
-#  output: 
 sub _breduce {
     
     local($_)= @_;
@@ -912,41 +688,57 @@ __END__
 
 =head1 NAME
 
-UMLS::Interface::ICFinder  - provides the information content 
-of the CUIs in the UMLS for the modules in the 
-UMLS::Interface package.
-
-=head1 DESCRIPTION
-
-This package provides the information content of the CUIs in the 
-UMLS for the modules in the UMLS::Interface package.
-
-For more information please see the UMLS::Interface.pm 
-documentation. 
+UMLS::Interface::ICFinder - Perl interface to support the UMLS::Interface.pm which 
+is an interface to the Unified Medical Language System (UMLS). 
 
 =head1 SYNOPSIS
 
  #!/usr/bin/perl
 
  use UMLS::Interface::CuiFinder;
- use UMLS::Interface::ICFinder;
- use UMLS::Interface::ErrorHandler;
 
+ use UMLS::Interface::ICFinder;
+ 
  %params = ();
 
- $params{"realtime"} = 1;
-
  $cuifinder = UMLS::Interface::CuiFinder->new(\%params); 
+
  die "Unable to create UMLS::Interface::CuiFinder object.\n" if(!$cuifinder);
 
+ ($errCode, $errString) = $cuifinder->_getError();
+
+ die "$errString\n" if($errCode);
+ 
+    
  $icfinder = UMLS::Interface::ICFinder->new(\%params, $cuifinder); 
+
  die "Unable to create UMLS::Interface::ICFinder object.\n" if(!$icfinder);
 
+ ($errCode, $errString) = $icfinder->_getError();
+
+ die "$errString\n" if($errCode);
+ 
  $concept = "C0037303";
 
  $ic = $icfinder->_getIC($concept);
 
  $hash = $icfinder->_getPropagationCuis();
+ 
+ if(!( $icfinder->_checkError())) {
+     print "No errors: All is good\n";
+ }
+ else {
+     my ($returnCode, $returnString) = $icfinder->_getError();
+     print STDERR "$returnString\n";
+ }
+
+=head1 ABSTRACT
+
+This package provides a Perl interface to the Unified Medical Language 
+System. The package is set up to access pre-specified sources of the UMLS
+present in a mysql database.  The package was essentially created for use 
+with the UMLS::Similarity package for measuring the semantic relatedness 
+of concepts.
 
 =head1 INSTALL
 
@@ -969,50 +761,21 @@ details of these can be found in the ExtUtils::MakeMaker
 documentation. However, it is highly recommended not messing around
 with other parameters, unless you know what you're doing.
 
-=head2 PROPAGATION
+=head1 DESCRIPTION
 
-The Information Content (IC) is  defined as the negative log 
-of the probability of a concept. The probability of a concept, 
-c, is determine by summing the probability of the concept 
-(P(c)) ocurring in some text plus the probability its decendants 
-(P(d)) occuring in some text:
+This package provides a Perl interface to the Unified Medical 
+Language System (UMLS). The UMLS is a knowledge representation 
+framework encoded designed to support broad scope biomedical 
+research queries. There exists three major sources in the UMLS. 
+The Metathesaurus which is a taxonomy of medical concepts, the 
+Semantic Network which categorizes concepts in the Metathesaurus, 
+and the SPECIALIST Lexicon which contains a list of biomedical 
+and general English terms used in the biomedical domain. The 
+UMLS-Interface package is set up to access the Metathesaurus
+and the Semantic Network present in a mysql database.
 
-P(c*) = P(c) + \sum_{d\exists decendant(c)} P(d)
-
-The initial probability of a concept (P(c)) and its decendants 
-(P(d)) is obtained by dividing the number of times a concept is 
-seen in the corpus (freq(d)) by the total number of concepts (N):
-
-P(d) = freq(d) / N
-
-Not all of the concepts in the taxonomy will be seen in the corpus. 
-We have the option to use Laplace smoothing, where the frequency 
-count of each of the concepts in the taxonomy is incremented by one. 
-The advantage of doing this is that it avoides having a concept that 
-has a probability of zero. The disadvantage is that it can shift the 
-overall probability mass of the concepts from what is actually seen 
-in the corpus. 
-
-=head2 PROPAGATION IN REALTIME
-
-The algorithm to determine the information content of a CUI in real 
-time is as follows:
-
-        1. get all of its decendants using the DFS
-
-        2. looping through the frequency file computing the 
-           probability of the decendants and storing this 
-           information
-
-        3. sum the probability of the decedants and the CUI 
-
-        4. calculate the IC which is defined as the negative log of 
-           the probabilty of the concept (which is the sum from
-           step 3)
-
-
-In order to run the propagation in real time, we require the frequency 
-counts of a list of CUIs to be given to us. 
+For more information please see the UMLS::Interface.pm 
+documentation. 
 
 =head1 SEE ALSO
 
@@ -1036,7 +799,7 @@ Ted Pedersen <tpederse@d.umn.edu>
 
  Siddharth Patwardhan, University of Utah, Salt Lake City
  sidd at cs.utah.edu
-
+ 
  Serguei Pakhomov, University of Minnesota Twin Cities
  pakh0002 at umn.edu
 
