@@ -148,7 +148,7 @@ this program; if not, write to:
 use UMLS::Interface;
 use Getopt::Long;
 
-GetOptions( "version", "help", "debug", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "config=s" );
+eval(GetOptions( "version", "help", "debug", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "config=s")) or die ("Please check the above mentioned option(s).\n");
 
 
 #  if help is defined, print out help
@@ -242,7 +242,7 @@ foreach my $cui (@c) {
     }
 
     #  make certain cui exists in this view
-    if($umls->checkConceptExists($cui) == 0) { next; }	
+    if($umls->exists($cui) == 0) { next; }	
     
     my @cuis = $umls->getRelated($cui, $rel); 
     
@@ -321,7 +321,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: getRelated.pl,v 1.8 2010/03/31 19:38:02 btmcinnes Exp $';
+    print '$Id: getRelated.pl,v 1.10 2010/05/11 20:04:46 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
